Finding information about the timetable
=======================================

Timetables are provided in several ways in AlekSIS. Using the different
views, it is possible to both find information about the regular
lessons taking place, as well as up-to-date information generated from
most recent information, e.g. substitutions, cancellations, or extra lessons.

Viewing the personal timetable
------------------------------

One of the most useful features is the ability to see your daily or weekly
timetable at a glance – with all recent information included. This view,
called "My timetable", can be accessed in two ways: Just add the timetable
widget to the dashboard or use the menu entry `Timetables → My timetable`.
On this page, you can switch between different days (on mobile devices)
or different weeks (on desktop devices) to see future information.

Smart plan
~~~~~~~~~~

By default, the personal timetable id displayed in `smart plan` mode.
This means that all available information, like substitutions or
cancellations, is merged into the regular plan to create an up-to-date
version of the timetable. At one glance, the actual timetable for a
specific day can thus be viewed.

Using the button `Show regular timetable` above the plan, the view can
be switched into regular mode, showing only what was planned ahead,
without up-to-date information.

.. image:: ../_static/my_timetable.png
  :width: 600
  :alt: My timetable

The colours of the lessons are defined by the subject of the lesson,
and was probably imported from a time-tabling software. In addition,
the following highlighting is done for changes:

 * Substituted lessons are decorated with a red border, and changes
   in the lesson data are struck through and replaced with the
   new information
 * Cancelled lessons have their background removed, and a `Cancelled`
   label added
 * Remarks from the substitution plan are added in italics underneath
   the lesson information

Dashboard widget
~~~~~~~~~~~~~~~~

A dashboard widget is provided that shows the `smart plan` for the current
day. Right when logging into AlekSIS, or opening the PWA, the timetable
can thus be immediately viewed.

The widget needs to be enabled by an administrator.

Week timetables
---------------

Using the menu entry `Timetables → All timetables` will give you access
to all timetables of your institution (or whatever your administrator
allowed you to see). It's divided into three main sections:

 * Teachers
 * Groups
 * Rooms

.. image:: ../_static/all_timetables.png
  :width: 600
  :alt: All timetables

If you open one of these timetables, by default you see the `smart plan`
of the current week. By clicking on `Show regular plan` or using the `print`
button, you can access the corresponding regular plan. To easily jump between
timetables, every teacher, subject, or group short name is linked to the
respective timetable.

.. image:: ../_static/class_timetable.png
  :width: 600
  :alt: Class timetable

The `print` button will generate the currently displayed plan as a PDF
file, which can either be printed, or used for display on digital signage.

.. image:: ../_static/print_timetable.png
  :width: 600
  :alt: Print timetable
